Changelog
=========


1.1 (2024-06-14)
----------------

- depend on zope.sendmail<=6.1 and add note to README to remove it for zope.sendmail >=6.2 [MrTango]


1.0 (2024-02-08)
----------------

- Initial release.
  [MrTango]
